mysql.exceptions.base

Package mysql :: Package exceptions :: Module base |
[hide private]
[frames] | no frames]

# Module base

source code

Base exception classes.

There is an Error exception that is the base for all other exceptions in this library.

Exceptions that emanate from MySQL itself are derived from MySQL_Error.

Classes | [hide private]
`` | Error Base class for all MySQL exceptions.
`` | MySQL_Error Base class for all MySQL exceptions that have an error code.

Variables | [hide private]
`` | __version__ = `'$Revision: 1.3 $'`

Variables Details | [hide private]

    ### __version__ Value:
        '$Revision: 1.3 $'